==> haskell-x509-system-1.6.4-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509-system.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-system
version: 1.6.4
id: x509-system-1.6.4-KrQrp9ANFMlLdIdHg4WE94
key: x509-system-1.6.4-KrQrp9ANFMlLdIdHg4WE94
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    System.X509 System.X509.Unix System.X509.MacOS
abi: 74ccd21c4bc6dc174184eb62ac905eed
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/x509-system-1.6.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/x509-system-1.6.4
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/x509-system-1.6.4
hs-libraries: HSx509-system-1.6.4-KrQrp9ANFMlLdIdHg4WE94
depends:
    base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    directory-1.3.0.0 filepath-1.4.1.1 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    pem-0.2.2-CkEwei5500yF2642aAaOAi process-1.4.3.0
    x509-1.6.5-1lNlFxDfEv2287NoJBDt9f
    x509-store-1.6.2-2JTK3MuGtMw4U8lTBVjl8Z
haddock-interfaces: /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html: /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-system-1.6.4-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509-system.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-system
version: 1.6.4
id: x509-system-1.6.4-K0F0RRwB7cE65T9KHom1Fv
key: x509-system-1.6.4-K0F0RRwB7cE65T9KHom1Fv
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    System.X509 System.X509.Unix System.X509.MacOS
abi: 9f3d1c71e1515d2ddfd81fbccd37e512
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/x509-system-1.6.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/x509-system-1.6.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/x509-system-1.6.4
hs-libraries: HSx509-system-1.6.4-K0F0RRwB7cE65T9KHom1Fv
depends:
    base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    directory-1.3.0.0 filepath-1.4.1.1 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    pem-0.2.2-CkEwei5500yF2642aAaOAi process-1.4.3.0
    x509-1.6.5-68mvIApsT0uDqkSQT4g0UR
    x509-store-1.6.2-74kkIvSUwrzH9gu3EuH7wA
haddock-interfaces: /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html: /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
